package Mqtt.config;

import lombok.extern.slf4j.Slf4j;
import org.eclipse.paho.client.mqttv3.IMqttDeliveryToken;
import org.eclipse.paho.client.mqttv3.MqttCallback;
import org.eclipse.paho.client.mqttv3.MqttMessage;

import java.util.Base64;

@Slf4j
public class PushCallback implements MqttCallback {

    private final LocalCacheManager cacheManager;

    public PushCallback(LocalCacheManager cacheManager) {
        this.cacheManager = cacheManager;
    }

    @Override
    public void connectionLost(Throwable cause) {
        log.warn("MQTT连接丢失：{}", cause.getMessage());
    }

    @Override
    public void messageArrived(String topic, MqttMessage message) {
        byte[] payloadBytes = message.getPayload(); // 原始二进制数据

        // 打印原始字节数据（十六进制）
        log.info("收到订阅消息，主题：{}，原始字节：{}", topic, bytesToHex(payloadBytes));

        // 可选：编码为 Base64 以供缓存或上传
        String base64Payload = Base64.getEncoder().encodeToString(payloadBytes);
        log.info("Base64 编码后：{}", base64Payload);

        // 缓存 base64 表达的数据（可替换为你自己的处理逻辑）
        cacheManager.cache(base64Payload);
    }

    @Override
    public void deliveryComplete(IMqttDeliveryToken token) {
        log.debug("消息发送完成");
    }

    // 辅助方法：转 16 进制字符串用于日志打印
    private String bytesToHex(byte[] bytes) {
        StringBuilder sb = new StringBuilder();
        for (byte b : bytes) {
            sb.append(String.format("%02X ", b));
        }
        return sb.toString().trim();
    }
}
