package Mqtt.controller;

import Mqtt.config.MQTTConfig;
import Mqtt.service.MQTTServer;
import com.google.gson.Gson;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.Map;
import java.util.concurrent.CompletableFuture;

/**
 * MQTT 控制器，负责消息发布与订阅接口
 */
@RestController
@RequestMapping("/mqtt")
public class MqttController implements ApplicationRunner {

    @Autowired
    private MQTTServer mqttServer;

    @Autowired
    private Gson gson;

    @Autowired
    private MQTTConfig mqttConfig;

    /**
     * 应用启动后自动订阅配置中的主题
     */
    @Override
    public void run(ApplicationArguments args) {
        CompletableFuture.runAsync(() -> {
            String topic = mqttConfig.getSubscriber().getDefaultTopic();
            mqttServer.init(topic, 1);  // 你也可以从 config.getSubscriber().getQos() 获取
            System.out.println("自动订阅：" + topic);
        });
    }

    /**
     * 接收终端数据并上送（POST JSON）
     */
    @PostMapping("/upload")
    public ResponseEntity<String> upload(@RequestBody Map<String, Object> raw) {
        String json = gson.toJson(raw);
        mqttServer.sendMQTTMessage(
                mqttConfig.getPublisher().getDefaultTopic(),
                json,
                1  // 默认 QoS 也可以从 config 中读取
        );
        return ResponseEntity.ok("数据已上送");
    }

    /**
     * 测试接口：发送消息到任意 Topic
     */
    @GetMapping("/test-publish")
    public ResponseEntity<String> testPublish(
            @RequestParam String topic,
            @RequestParam String msg,
            @RequestParam(defaultValue = "1") int qos) {
        mqttServer.sendMQTTMessage(topic, msg, qos);
        return ResponseEntity.ok("已发送到主题: '" + topic + "'，内容: " + msg + "，QoS: " + qos);
    }

    /**
     * 手动订阅指定主题
     */
    @GetMapping("/manual-subscribe")
    public ResponseEntity<String> manualSubscribe(
            @RequestParam String topic,
            @RequestParam(defaultValue = "1") int qos) {
        mqttServer.init(topic, qos);
        return ResponseEntity.ok("已手动订阅主题: '" + topic + "'，QoS: " + qos);
    }
}
